@@ -1,114 +1,74 @@
 package Path::Class::Dir;
 
 use strict;
+use File::Spec;
 use Path::Class::File;
 use Path::Class::Entity;
 use base qw(Path::Class::Entity);
 
-use IO::Dir ();
-use File::Path ();
-
 sub new {
   my $self = shift->SUPER::new();
-  my $s = $self->_spec;
   
-  my $first = (@_ == 0     ? $s->curdir :
-	       $_[0] eq '' ? (shift, $s->rootdir) :
+  my $first = (@_ == 0     ? File::Spec->curdir :
+	       $_[0] eq '' ? (shift, File::Spec->rootdir) :
 	       shift()
 	      );
   
-  ($self->{volume}, my $dirs) = $s->splitpath($first, 1);
-  $self->{dirs} = [map $s->splitdir($_), $dirs, @_];
+  my ($volume, $dirs) = File::Spec->splitpath($first, 1);
+  my @dirs = File::Spec->splitdir($dirs);
+  push @dirs, map File::Spec->splitdir($_), @_;
+
+  $self->{dirs} = \@dirs;
+  $self->{volume} = $volume;
 
   return $self;
 }
 
-sub as_foreign {
-  my ($self, $type) = @_;
-
-  my $foreign = do {
-    local $self->{file_spec_class} = $self->_spec_class($type);
-    $self->SUPER::new;
-  };
-  
-  # Clone internal structure
-  $foreign->{volume} = $self->{volume};
-  my ($s, $fs) = ($self->_spec, $foreign->_spec);
-  $foreign->{dirs} = [ map {$_ eq $s->updir ? $fs->updir : $_} @{$self->{dirs}}];
-  return $foreign;
-}
-
 sub stringify {
   my $self = shift;
-  my $s = $self->_spec;
-  return $s->catpath($self->{volume},
-		     $s->catdir(@{$self->{dirs}}),
-		     '');
+  return File::Spec->catpath($self->{volume},
+			     File::Spec->catdir(@{$self->{dirs}}),
+			     '');
 }
 
-sub is_dir { 1 }
 sub volume { shift()->{volume} }
 
 sub file {
-  local $Path::Class::Foreign = $_[0]->{file_spec_class} if $_[0]->{file_spec_class};
   return Path::Class::File->new(@_);
 }
 
 sub subdir {
   my $self = shift;
-  return $self->new($self, @_);
+  return ref($self)->new($self, @_);
 }
 
 sub parent {
   my $self = shift;
+  my $class = ref($self);
   my $dirs = $self->{dirs};
-  my ($curdir, $updir) = ($self->_spec->curdir, $self->_spec->updir);
+  my ($curdir, $updir) = (File::Spec->curdir, File::Spec->updir);
 
   if ($self->is_absolute) {
-    my $parent = $self->new($self);
+    my $parent = $class->new($self);
     pop @{$parent->{dirs}};
     return $parent;
 
   } elsif ($self eq $curdir) {
-    return $self->new($updir);
+    return $class->new($updir);
 
   } elsif (!grep {$_ ne $updir} @$dirs) {  # All updirs
-    return $self->new($self, $updir); # Add one more
+    return $class->new($self, $updir); # Add one more
 
   } elsif (@$dirs == 1) {
-    return $self->new($curdir);
+    return $class->new($curdir);
 
   } else {
-    my $parent = $self->new($self);
+    my $parent = $class->new($self);
     pop @{$parent->{dirs}};
     return $parent;
   }
 }
 
-sub open  { IO::Dir->new(@_) }
-sub mkpath { File::Path::mkpath(''.shift(), @_) }  # Must stringify first arg
-sub rmtree { File::Path::rmtree(''.shift(), @_) }  # Must stringify first arg
-
-sub next {
-  my $self = shift;
-  unless ($self->{dh}) {
-    $self->{dh} = $self->open or die "Can't open directory $self: $!";
-  }
-  
-  my $next = $self->{dh}->read;
-  unless (defined $next) {
-    delete $self->{dh};
-    return undef;
-  }
-  
-  # Have to figure out whether it's a file or directory
-  my $file = Path::Class::File->new($self, $next);
-  if (-d $file) {
-    $file = $self->new($self, $next);
-  }
-  return $file;
-}
-
 1;
 __END__
 
@@ -139,10 +99,6 @@ Path::Class::Dir - Objects representing directories
   
   my $abs = $dir->absolute; # Transform to absolute path
   my $rel = $abs->relative; # Transform to relative path
-  my $rel = $abs->relative('/foo'); # Relative to /foo
-  
-  print $dir->as_foreign('MacOS'); # :foo:bar:
-  print $dir->as_foreign('Win32'); #  foo\bar
 
 =head1 DESCRIPTION
 
@@ -272,36 +228,12 @@ directories:
 =item $abs = $dir->absolute
 
 Returns a C<Path::Class::Dir> object representing C<$dir> as an
-absolute path.  An optional argument, given as either a string or a
-C<Path::Class::Dir> object, specifies the directory to use as the base
-of relativity - otherwise the current working directory will be used.
+absolute path.
 
 =item $rel = $dir->relative
 
 Returns a C<Path::Class::Dir> object representing C<$dir> as a
-relative path.  An optional argument, given as either a string or a
-C<Path::Class::Dir> object, specifies the directory to use as the base
-of relativity - otherwise the current working directory will be used.
-
-=item $foreign = $dir->as_foreign($type)
-
-Returns a C<Path::Class::Dir> object representing C<$dir> as it would
-be specified on a system of type C<$type>.  Known types include
-C<Unix>, C<Win32>, C<Mac>, C<VMS>, and C<OS2>, i.e. anything for which
-there is a subclass of C<File::Spec>.
-
-Any generated objects (subdirectories, files, parents, etc.) will also
-retain this type.
-
-=item $foreign = Path::Class::Dir->new_foreign($type, @args)
-
-Returns a C<Path::Class::Dir> object representing C<$dir> as it would
-be specified on a system of type C<$type>.  Known types include
-C<Unix>, C<Win32>, C<Mac>, C<VMS>, and C<OS2>, i.e. anything for which
-there is a subclass of C<File::Spec>.
-
-The arguments in C<@args> are the same as they would be specified in
-C<new()>.
+relative path.
 
 =back
 
