@@ -1,22 +1,23 @@
 package Path::Class::File;
 
 use strict;
+use File::Spec;
 use Path::Class::Dir;
 use Path::Class::Entity;
 use base qw(Path::Class::Entity);
 
-use IO::File ();
-use File::stat ();
-
 sub new {
   my $self = shift->SUPER::new;
   my $file = pop();
-  my @dirs = @_;
-
-  my ($volume, $dirs, $base) = $self->_spec->splitpath($file);
+  my ($volume, $dirs, $base) = File::Spec->splitpath($file);
   
+  my @dirs;
   if (length $dirs) {
-    push @dirs, $self->_spec->catpath($volume, $dirs, '');
+    push @dirs, Path::Class::Dir->new(File::Spec->catpath($volume, $dirs, ''));
+  }
+  
+  if (@_) {
+    unshift @dirs, Path::Class::Dir->new(@_);
   }
   
   $self->{dir}  = @dirs ? Path::Class::Dir->new(@dirs) : undef;
@@ -25,25 +26,16 @@ sub new {
   return $self;
 }
 
-sub as_foreign {
-  my ($self, $type) = @_;
-  local $Path::Class::Foreign = $self->_spec_class($type);
-  my $foreign = ref($self)->SUPER::new;
-  $foreign->{dir} = $self->{dir}->as_foreign($type) if defined $self->{dir};
-  $foreign->{file} = $self->{file};
-  return $foreign;
-}
-
 sub stringify {
   my $self = shift;
   return $self->{file} unless defined $self->{dir};
-  return $self->_spec->catfile($self->{dir}, $self->{file});
+  return File::Spec->catfile($self->{dir}, $self->{file});
 }
 
 sub dir {
   my $self = shift;
   return $self->{dir} if defined $self->{dir};
-  return Path::Class::Dir->new($self->_spec->curdir);
+  return Path::Class::Dir->new(File::Spec->curdir);
 }
 
 sub volume {
@@ -52,10 +44,6 @@ sub volume {
   return $self->{dir}->volume;
 }
 
-sub open  { IO::File->new(@_) }
-sub stat  { File::stat::stat("$_[0]") }
-sub lstat { File::stat::lstat("$_[0]") }
-
 1;
 __END__
 
@@ -162,36 +150,12 @@ containing this file.
 =item $abs = $file->absolute
 
 Returns a C<Path::Class::File> object representing C<$file> as an
-absolute path.  An optional argument, given as either a string or a
-C<Path::Class::Dir> object, specifies the directory to use as the base
-of relativity - otherwise the current working directory will be used.
+absolute path.
 
 =item $rel = $file->relative
 
 Returns a C<Path::Class::File> object representing C<$file> as a
-relative path.  An optional argument, given as either a string or a
-C<Path::Class::Dir> object, specifies the directory to use as the base
-of relativity - otherwise the current working directory will be used.
-
-=item $foreign = $file->as_foreign($type)
-
-Returns a C<Path::Class::File> object representing C<$file> as it would
-be specified on a system of type C<$type>.  Known types include
-C<Unix>, C<Win32>, C<Mac>, C<VMS>, and C<OS2>, i.e. anything for which
-there is a subclass of C<File::Spec>.
-
-Any generated objects (subdirectories, files, parents, etc.) will also
-retain this type.
-
-=item $foreign = Path::Class::File->new_foreign($type, @args)
-
-Returns a C<Path::Class::File> object representing a file as it would
-be specified on a system of type C<$type>.  Known types include
-C<Unix>, C<Win32>, C<Mac>, C<VMS>, and C<OS2>, i.e. anything for which
-there is a subclass of C<File::Spec>.
-
-The arguments in C<@args> are the same as they would be specified in
-C<new()>.
+relative path.
 
 =back
 
